﻿using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using API.BaseModel;
using System.Reflection;

namespace API.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class AutoController : Controller
    {
        [Route("GetSongs")]
        [HttpGet]
        public List<Auto> GetSongs()
        {
            using (AstashinApiContext DB = new AstashinApiContext())
            {
                return DB.Autos.Include("IdArtistNavigation").Include("IdGenreNavigation").ToList();
            }
        }


        [Route("PostSong")]
        [HttpPost]
        public IActionResult PostSong([FromBody] Auto auto)
        {
            if (auto == null)
            {
                return BadRequest("Песня пустая");
            }
            auto.IdAuto = default(int);
            using (AstashinApiContext DB = new AstashinApiContext())
            {
                DB.Autos.Add(auto);
                try
                {
                    DB.SaveChanges();
                    return Ok();
                }
                catch (Exception ex)
                {
                    return BadRequest($"{ex.Message}");
                }
            }
        }

        [Route("PutSong")]
        [HttpPut]
        public IActionResult PutProduct([FromBody] Auto auto)
        {
            Auto? UpdateSong;
            using (AstashinApiContext DB = new AstashinApiContext())
            {
                UpdateSong = DB.Autos.Find(auto.IdAuto);
                if (UpdateSong is null)
                {
                    return BadRequest("Автомобиля нет");
                }
                UpdateSong.Brand = auto.Brand;
                UpdateSong.Model = auto.Model;
                UpdateSong.Year = auto.Year;
                UpdateSong.Color = auto.Color;
                UpdateSong.IdPriceNavigation = auto.IdPriceNavigation;
                UpdateSong.IdCarBodyNavigation = auto.IdCarBodyNavigation;
                try
                {
                    DB.SaveChanges();
                    return Ok();
                }
                catch (Exception ex)
                {
                    return BadRequest(ex.Message);
                }
            }
        }


        [Route("DeleteSong")]
        [HttpDelete]
        public IActionResult DeleteSong([FromQuery] int id)
        {
            using (AstashinApiContext DB = new AstashinApiContext())
            {
                Auto auto = DB.Autos.Find(id);
                if (auto is null)
                {
                    return BadRequest("Такой нет");
                }
                DB.Autos.Remove(auto);
                try
                {
                    DB.SaveChanges();
                    return Ok();
                }
                catch (Exception)
                {
                    return BadRequest("Что то пошло не так");
                }
            }
        }

    }
}
